@@ -9,6 +9,7 @@ import wsgiref.simple_server
 
 from .request import VRequest
 from .response import VResponse
+from .loginmanager import VialLoginManager
 
 
 try:
@@ -52,14 +53,21 @@ class Vial():
     def __call__(self, environ, respond):
         request = VRequest(environ)
         try:
-            status, headers, body = self.handle(request)
+            r = self.handle(request)
+            if type(r) == tuple and len(r) == 3:
+                status, headers, body = r
+            elif r is None:
+                status, headers, body = self.response(501)
+            else:
+                self.logger.error(f"Vial.handle returned incorrect type {type(r)} for {request}")
+                status, headers, body = self.response(500)
         except Exception:
             if has_nxtools:
                 nxtools.log_traceback()
             else:
                 self.logger.error(f"Unhandled exception")
                 self.logger.debug(format_traceback())
-            status, headers, body = self.response.text("Internal server error", 500)
+            status, headers, body = self.responsei(500)
 
         respond(status, headers)
         if inspect.isgeneratorfunction(body):
@@ -68,7 +76,7 @@ class Vial():
             yield body
 
     def handle(self, request:VRequest):
-        return self.response.text("Vial.handle is not implemented", 501)
+        return self.response(501)
 
     def serve(self, host:str="", port:int=8080, log_requests:bool=True):
         """Start a development server"""
