@@ -2,8 +2,8 @@ import json
 from http import HTTPStatus
 
 
-def format_status(code):
-    return f"{code} {HTTPStatus(code).phrase}"
+def format_status(status):
+    return f"{status} {HTTPStatus(status).phrase}"
 
 
 def response_type(func):
@@ -23,6 +23,15 @@ def response_type(func):
 
 
 class VResponse():
+    def __call__(self, status=200, message=None, **kwargs):
+        data = {
+            "response" : status,
+            "message" : HTTPStatus(status).phrase if message is None else message,
+            **kwargs
+        }
+        return self.json(data, status=status)
+
+
     @response_type
     def text(self, body, status):
         if body is None:
